#
# This file is part of Astarte.
#
# Copyright 2019 Ispirata Srl
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

defmodule Astarte.Device.TortoiseHandler do
  @moduledoc false

  require Logger
  use Tortoise.Handler

  @impl true
  def init(args) do
    state = %{
      device_pid: Keyword.fetch!(args, :device_pid)
    }

    {:ok, state}
  end

  @impl true
  def connection(status, %{device_pid: device_pid} = state) do
    :gen_statem.cast(device_pid, {:connection_status, status})
    {:ok, state}
  end

  @impl true
  def subscription(status, topic_filter, state) do
    _ = Logger.info("Subscription on topic #{inspect(topic_filter)} status: #{inspect(status)}")
    {:ok, state}
  end

  @impl true
  def handle_message(topic_levels, payload, %{device_pid: device_pid} = state) do
    :gen_statem.cast(device_pid, {:msg, topic_levels, payload})
    {:ok, state}
  end
end
